@@ -1,3 +1,5 @@
+# type: ignore
+
 from pygments.lexer import inherit
 from pygments.lexers.sql import MySqlLexer
 from pygments.token import Keyword
@@ -7,6 +9,5 @@ class MyCliLexer(MySqlLexer):
     """Extends MySQL lexer to add keywords."""
 
     tokens = {
-        'root': [(r'\brepair\b', Keyword),
-                 (r'\boffset\b', Keyword), inherit],
+        "root": [(r"\brepair\b", Keyword), (r"\boffset\b", Keyword), inherit],
     }
